% leg.m
% Plays around with large-ensemble global (leg) properties. Computes
% probabilites of causation, for Marotzke (WIREs 2018). 
%
% To begin with, I want to re-trace Forster et al. (JGR-A) in estimating
% effective radiative forcing. 
% Copyright Jochem Marotzke, MPI-M, 15 February 2016
%
% 4 July 2016: Add AMOC at 26N
% 7 July 2016: Add Arctic sea-ice area (SIA)
% 13 July 2016: Add ocean heat content (OHC) above 2000 m.
% 14 July 2016: Use corrected SIA files and full OHC time series.
% April 2017: Pushed toward paper
% 27 June 2017: I recycle exact code lines for computations of simulated
% trends of different quantities.  That makes copy-and-paste much easier, 
% but disallows later analyses of trends.  In the long run, it's probably 
% better to re-name trends such that they can be identified and worked upon 
% later. 
% 14 October 2018:  Added the calculations for the period 2036--2050.  This
% requires using the completely re-done scenario simulations out to 2100.
% Comparison against the simulations that were run only to 2035 shows that
% probabilities differ by only two to three percentage points, max. 

% 14 October 2018: Version for repository. 

 clear all, format compact
% close all   % Sometimes needed to avoid memory issues ????  
 set(0,'DefaultFigureColor','white')
 set(0,'DefaultAxesFontSize',14)
%
% Write unique logfile (diary) each time.  Naming a bit awkward because
% Matlab datestring syntax is incompatible with Windows naming convention.
% Note: must say "diary off" to see contents in buffer. 

 texttime=datestr(now);
 diary(['log',texttime(1:11),'_',texttime(13:14),'_',texttime(16:17),...
     '_',texttime(19:20),'.txt'])
 disp(' ')
 disp(' ')
 disp('*****************************************************************************************')
 disp(['Beginning of run @ ', datestr(now)])
 disp(' ')
 help leg
 
%% First, read in observations

% HadCRUT4 GMST: 
 HadCRUT4=load('HadCRUT.4.5.0.0.annual_ns_avg.txt');
 GMST_obs_years=HadCRUT4(1:end-1,1);       % Leave out incomplete year 2017
 GMST_obs=HadCRUT4(1:end-1,2);
%  GMST_obs_years=HadCRUT4(:,1);     % Don't leave out incomplete year 2017
%  GMST_obs=HadCRUT4(:,2);
% To plot the record for all full years:
  HadCRUT4_plot(HadCRUT4(1:end-1,1),HadCRUT4(1:end-1,2))
% To deal with different reference periods: 
 GMST_mean_19Century=mean(GMST_obs(1:51))
 GMST_mean_20Century=mean(GMST_obs(52:151))
 GMST_diff_20_19C=GMST_mean_20Century-GMST_mean_19Century

% RAPID AMOC at 26N:
 load moc_transports_end_feb2017
% Variable name: MOC_mar_hc10; JG counts days since 1 April 2004.  The
% first day of data return, 2 April 2004, therefore has JG = 1. Record ends
% in February 2016. In the first instance, ignore that 2004 and 2015 are
% incomplete. Notice that nominally there is a data entry every half-day. 

% 16 Nov 2017:  the newest data version has -99999 as dummy values in
% the first ten entries (I assume they did the 10-day averaging that's needed to
% make the numbers meaningful.  But I must do replacement to avoid
% contamination with dummies:  

 MOC_mar_hc10(1:10)=MOC_mar_hc10(11);   % Set first ten entries to 11th.
 MOC_mar_hc10(9422:end)=MOC_mar_hc10(9421);   % Ditto for last ten entries.

% Now the tedious business of converting to annual means: 
 AMOC_obs_years = 2004:2016;
%  NumDays = [29+31+30+31+31+30+31+30+31,365,365,365,366,365,365,365,366,...
%      365,365,365-31-30-31+11];    
 NumDays = [29+31+30+31+31+30+31+30+31,365,365,365,366,365,365,365,366,...
     365,365,365, 366];    
 NumDays_cum=[0.5,cumsum(NumDays)];      % Dummy "0.5" as first entry 
 
 AMOC_obs=zeros(1,length(AMOC_obs_years)-1);
 
 for i=1:length(AMOC_obs_years) 
     AMOC_obs(i)=mean(MOC_mar_hc10(2*NumDays_cum(i):2*NumDays_cum(i+1)-1));
 end

% NH sea ice:
 SIA_NH_Mar_obs=load('Arctic_sea_ice_area_March_1953_2016.txt');
 SIA_NH_Sep_obs=load('Arctic_sea_ice_area_September_1953_2016.txt');
 SIA_obs_years=1953:2016;
 SIA_NH_Mar_obs=SIA_NH_Mar_obs'*1.e-12;      % Convert to million km squared
 SIA_NH_Sep_obs=SIA_NH_Sep_obs'*1.e-12;      % Convert to million km squared
 
% Heat content (NOAA NCEP, formerly NODC; looks awfully smooth compared to 
% AR5 Figure 3.2...):

 NOAA_OHC_2000_yearly=load('h22-w0-2000m.txt');
 OHC_2000_obs_years=NOAA_OHC_2000_yearly(:,1);
 OHC_2000_obs=NOAA_OHC_2000_yearly(:,2);
 
 NOAA_OHC_2000_pentadal=load('pent_h22-w0-2000m.txt');
 OHC_2000_obs_years_pentadal=NOAA_OHC_2000_pentadal(:,1);
 OHC_2000_obs_pentadal=NOAA_OHC_2000_pentadal(:,2);
 
 
%% Next, read in model data, always in the order historical, RCP2.6, 
% RCP4.5. Always first read from netcdf and then "squeeze" into 2-D
% arrays. 

% First, GMST (note that first set has scenarios only out to 2035):

 GMST_hist_raw=ncread('hist_all_tsurf.nc','var169');
 GMST_hist=squeeze(GMST_hist_raw);    % GMST
 GMST_RCP2_6_raw=ncread('rcp2.6_all_tsurf.nc','var169');
 GMST_RCP2_6=squeeze(GMST_RCP2_6_raw);    % GMST
 GMST_RCP4_5_raw=ncread('rcp4.5_all_tsurf.nc','var169');
 GMST_RCP4_5=squeeze(GMST_RCP4_5_raw);    % GMST

% Read other set of scenario data, out to 2099.  I think they were
% completely new runs and hence are not the same realisations as the
% previous set):
 GMST_RCP2_6_long_raw=ncread('rcp26_2006-2099_ens_1-100.tsurf_mean.nc','tsurf');
 GMST_RCP2_6_long_mm=squeeze(GMST_RCP2_6_long_raw);    % GMST
 GMST_RCP4_5_long_raw=ncread('rcp45_2006-2099_ens_1-100.tsurf_mean.nc','tsurf');
 GMST_RCP4_5_long_mm=squeeze(GMST_RCP4_5_long_raw);    % GMST
% Convert from monthly to annual means:
 GMST_RCP2_6_long=zeros(100,94);
 GMST_RCP4_5_long=zeros(100,94);
 for iy=1:94
     GMST_RCP2_6_long(:,iy)=mean(GMST_RCP2_6_long_mm(:,(iy-1)*12+1:iy*12),2);
     GMST_RCP4_5_long(:,iy)=mean(GMST_RCP4_5_long_mm(:,(iy-1)*12+1:iy*12),2);
 end

% Second, TOA:
 TOA_hist_raw=ncread('hist_all_toa.nc','var178');
 TOA_hist=squeeze(TOA_hist_raw);    % TOA imbalance, positive downward
 TOA_RCP2_6_raw=ncread('rcp2.6_all_toa.nc','var178');
 TOA_RCP2_6=squeeze(TOA_RCP2_6_raw);    % GMST
 TOA_RCP4_5_raw=ncread('rcp4.5_all_toa.nc','var178');
 TOA_RCP4_5=squeeze(TOA_RCP4_5_raw);    % GMST

% Third, AMOC at 26N:
 amoc26N_hist_raw=ncread('hist_AMOC26N.nc','amoc26n');
 amoc26N_hist=squeeze(amoc26N_hist_raw); 
 amoc26N_RCP2_6_raw=ncread('rcp26_AMOC26N.nc','amoc26n');
 amoc26N_RCP2_6=squeeze(amoc26N_RCP2_6_raw); 
 amoc26N_RCP4_5_raw=ncread('rcp45_AMOC26N_all.nc','amoc26n');
 amoc26N_RCP4_5=squeeze(amoc26N_RCP4_5_raw);
% AMOC at 26N for long scenario runs (2006-2099; I think they were
% completely new runs and hence are not the same realisations as the
% previous set):
 amoc26N_RCP2_6_long_raw=ncread('AMOC_all_rcp26_mpiom_monitoring_ym.nc','amoc26n');
 amoc26N_RCP2_6_long=squeeze(amoc26N_RCP2_6_long_raw); 
 amoc26N_RCP4_5_long_raw=ncread('AMOC_all_rcp45_mpiom_monitoring_ym.nc','amoc26n');
 amoc26N_RCP4_5_long=squeeze(amoc26N_RCP4_5_long_raw); 
 
% Fourth, Arctic (NH) sea-ice area: 
 SIA_NH_hist_raw=ncread('hist_seaicearea_NH_mm.nc', 'sicomo');
 SIA_NH_RCP2_6_raw=ncread('rcp26_seaicearea_NH_mm.nc', 'sicomo');
 SIA_NH_RCP4_5_raw=ncread('cor_rcp45_seaicearea_NH_mm.nc', 'sicomo');
 
% Convert to million km squared.  Note: there is probably a factor of 100
% missing because of a mix-up of naming concentration sometimes as a 
% fraction and sometimes as a percentage. 
 SIA_NH_hist_raw=SIA_NH_hist_raw*1e-10;  
 SIA_NH_RCP2_6_raw=SIA_NH_RCP2_6_raw*1e-10;  
 SIA_NH_RCP4_5_raw=SIA_NH_RCP4_5_raw*1e-10;  
 
% Create separate arrays for March and September: 
 SIA_NH_Mar_hist=squeeze(SIA_NH_hist_raw(:,:,:,3:12:end));
 SIA_NH_Sep_hist=squeeze(SIA_NH_hist_raw(:,:,:,9:12:end));
 SIA_NH_Mar_RCP2_6=squeeze(SIA_NH_RCP2_6_raw(:,:,:,3:12:end));
 SIA_NH_Sep_RCP2_6=squeeze(SIA_NH_RCP2_6_raw(:,:,:,9:12:end));
 SIA_NH_Mar_RCP4_5=squeeze(SIA_NH_RCP4_5_raw(:,:,:,3:12:end));
 SIA_NH_Sep_RCP4_5=squeeze(SIA_NH_RCP4_5_raw(:,:,:,9:12:end));

% Fifth, ocean heat content:

%  OHC_2000_hist_raw=ncread('u2000m_ohc_1850-2015_exRCP45_allmembers.nc',...
%      'heat_content_J');
%  OHC_2000_hist_raw=OHC_2000_hist_raw*1e-22;
 OHC_2000_hist_RCP2_6_raw=ncread('ohc_u2000m_1850-2035_exRCP26-allmembers.nc',...
     'heat_content_J');
 OHC_2000_hist_RCP4_5_raw=ncread('ohc_u2000m_1850-2035_exRCP45-allmembers.nc',...
     'heat_content_J');
% Convert to 10^22 J:
 OHC_2000_hist_RCP2_6_raw=OHC_2000_hist_RCP2_6_raw*1e-22;
 OHC_2000_hist_RCP4_5_raw=OHC_2000_hist_RCP4_5_raw*1e-22;

% Load into separate arrays for historical, RCP2.6, and RCP4.5: 
 OHC_2000_hist=squeeze(OHC_2000_hist_RCP2_6_raw(1,1,:,1:156));
 OHC_2000_RCP2_6=squeeze(OHC_2000_hist_RCP2_6_raw(1,1,:,157:end));
 OHC_2000_RCP4_5=squeeze(OHC_2000_hist_RCP4_5_raw(1,1,:,157:end));
 
%% Define some helper arrays (ensemble size and time vectors):

 ens_size=size(GMST_hist,1);
 one_ens_size=ones(ens_size,1);       % Define vector of ones across ensemble
 
 time_raw=ncread('hist_all_tsurf.nc','time');   % Hours -- not so useful
 year_hist=(1850:1:2005);
 one_year_hist=ones(1,length(year_hist)); % Vector of ones along time

 time_RCP2_6_raw=ncread('rcp2.6_all_tsurf.nc','time');   % Hours -- not so useful
 year_RCP2_6=(2006:1:2035);
 one_year_RCP2_6=ones(1,length(year_RCP2_6)); % Vector of ones along time
 year_RCP2_6_long=(2006:1:2099);
 one_year_RCP2_6_long=ones(1,length(year_RCP2_6_long)); % Vector of ones along time
 
 time_RCP4_5_raw=ncread('rcp4.5_all_tsurf.nc','time');   % Hours -- not so useful
 year_RCP4_5=(2006:1:2035);
 one_year_RCP4_5=ones(1,length(year_RCP4_5)); % Vector of ones along time
 year_RCP4_5_long=(2006:1:2099);
 one_year_RCP4_5_long=ones(1,length(year_RCP4_5_long)); % Vector of ones along time
 

%% Some adjustment is needed. 

% First, convert GMST time series to anomalies with respect to period 
% 1961 to 1990. Do this for both simulations and observations. 
% On second thought: I need consisten reference periods, otherwise I cannot 
% combine TOA amd GMST! Pick an early reference period, without volcanoes. 

 ref_period_begin = 1861
 ref_period_end   = 1880
 
 i_rpb=find(year_hist==ref_period_begin,1,'first')
 i_rpe=find(year_hist==ref_period_end,1,'first')

 GMST_ref_period = mean(GMST_hist(:,i_rpb:i_rpe),2);    % Mean over ref period
 year_hist(i_rpb), year_hist(i_rpe)     % Just checking....
 
 GMST_hist=GMST_hist-GMST_ref_period*one_year_hist;
 GMST_RCP2_6=GMST_RCP2_6-GMST_ref_period*one_year_RCP2_6;
 GMST_RCP4_5=GMST_RCP4_5-GMST_ref_period*one_year_RCP4_5;
 GMST_RCP2_6_long=GMST_RCP2_6_long-GMST_ref_period*one_year_RCP2_6_long;
 GMST_RCP4_5_long=GMST_RCP4_5_long-GMST_ref_period*one_year_RCP4_5_long;
 
% Since simulated GMST is absolute (in Kelvin) and observations relative to
% the climatological reference period 1961-1990, I need to work extra on
% the observations to adjust them to the earlier reference period:

 clim_ref_period_begin = 1961
 clim_ref_period_end   = 1990
 
 i_orpb=find(GMST_obs_years==ref_period_begin,1,'first');
 i_orpe=find(GMST_obs_years==ref_period_end,1,'first');
 i_crpb=find(GMST_obs_years==clim_ref_period_begin,1,'first');
 i_crpe=find(GMST_obs_years==clim_ref_period_end,1,'first');

 GMST_obs_ref_period = mean(GMST_obs(i_orpb:i_orpe))
 GMST_clim_ref_period = mean(GMST_obs(i_crpb:i_crpe))       % Just checking
 
 GMST_obs_adj = GMST_obs - GMST_obs_ref_period;
%  GMST_obs_adj=GMST_obs 
 
% Second, as a quick fix, subtract TOA average over 1861 to 1880, a period 
% without major volcano.  Since ERF by that time was presumably small, TOA
% imbalance reflects drift in every single realization. 

 TOA_ref_period = mean(TOA_hist(:,i_rpb:i_rpe),2);    % Mean over ref period
 
 TOA_hist = TOA_hist-TOA_ref_period*one_year_hist;
 TOA_RCP2_6 = TOA_RCP2_6-TOA_ref_period*one_year_RCP2_6;
 TOA_RCP4_5 = TOA_RCP4_5-TOA_ref_period*one_year_RCP4_5;
 
% Now estimate ERF
 alpha = 1.1;               % From Table 9.5 AR5; assuming it's unchanged
 
 ERF_hist=TOA_hist+alpha*GMST_hist;
 ERF_RCP2_6=TOA_RCP2_6+alpha*GMST_RCP2_6;
 ERF_RCP4_5=TOA_RCP4_5+alpha*GMST_RCP4_5;
 
% For consistency, do the same for OHC. NB: as of 12 July 2016, historical
% goes until 2015, because I do not have the full scenario runs until 2035
% yet. 14 July 2016: Slowly getting corrected now.

 OHC_2000_ref_period = mean(OHC_2000_hist(:,i_rpb:i_rpe),2);  % Mean over ref period
 
 OHC_2000_hist = OHC_2000_hist - ...
     OHC_2000_ref_period*ones(1,length(OHC_2000_hist(1,:)));
 OHC_2000_RCP2_6 = OHC_2000_RCP2_6 - ...
     OHC_2000_ref_period*ones(1,length(OHC_2000_RCP2_6(1,:)));
 OHC_2000_RCP4_5 = OHC_2000_RCP4_5 - ...
     OHC_2000_ref_period*ones(1,length(OHC_2000_RCP4_5(1,:)));

%% Compare the two scenarios: 
 if 1==0 
     
 test_mean=mean(GMST_RCP2_6)-mean(GMST_RCP2_6_long(:,1:30));
 test_std=std(GMST_RCP2_6)-std(GMST_RCP2_6_long(:,1:30));
 figure(89), clf reset
 h1=plot([2006:2035], GMST_RCP2_6',[2006:2035], GMST_RCP2_6_long(:,1:30));
 h1=plot([2006:2035], GMST_RCP2_6_long(:,1:30));
 hold on
 h2=plot([2006:2035], test_mean,[2006:2035], test_std);
 legend(h2,'mean', 'std')

 end
 
%% Compute ensemble means and standard deviations for the various quantities. 

% Means:
 GMST_hist_ens_mean=mean(GMST_hist);
 GMST_RCP2_6_ens_mean=mean(GMST_RCP2_6);
 GMST_RCP4_5_ens_mean=mean(GMST_RCP4_5);

 TOA_hist_ens_mean=mean(TOA_hist);
 TOA_RCP2_6_ens_mean=mean(TOA_RCP2_6);
 TOA_RCP4_5_ens_mean=mean(TOA_RCP4_5);
 
 ERF_hist_ens_mean=mean(ERF_hist);
 ERF_RCP2_6_ens_mean=mean(ERF_RCP2_6);
 ERF_RCP4_5_ens_mean=mean(ERF_RCP4_5);
 
 amoc26N_hist_ens_mean=mean(amoc26N_hist);
 amoc26N_RCP2_6_ens_mean=mean(amoc26N_RCP2_6);
 amoc26N_RCP4_5_ens_mean=mean(amoc26N_RCP4_5);
 amoc26N_RCP2_6_long_ens_mean=mean(amoc26N_RCP2_6_long);
 amoc26N_RCP4_5_long_ens_mean=mean(amoc26N_RCP4_5_long);
 
 SIA_NH_Sep_hist_ens_mean=mean(SIA_NH_Sep_hist);
 SIA_NH_Sep_RCP2_6_ens_mean=mean(SIA_NH_Sep_RCP2_6);
 SIA_NH_Sep_RCP4_5_ens_mean=mean(SIA_NH_Sep_RCP4_5);
 
 SIA_NH_Mar_hist_ens_mean=mean(SIA_NH_Mar_hist);
 SIA_NH_Mar_RCP2_6_ens_mean=mean(SIA_NH_Mar_RCP2_6);
 SIA_NH_Mar_RCP4_5_ens_mean=mean(SIA_NH_Mar_RCP4_5);
 
 OHC_2000_hist_ens_mean=mean(OHC_2000_hist);
 OHC_2000_RCP2_6_ens_mean=mean(OHC_2000_RCP2_6);
 OHC_2000_RCP4_5_ens_mean=mean(OHC_2000_RCP4_5);

% Standard deviations: 
 GMST_hist_ens_std=std(GMST_hist);
 GMST_RCP2_6_ens_std=std(GMST_RCP2_6);
 GMST_RCP4_5_ens_std=std(GMST_RCP4_5);

 TOA_hist_ens_std=std(TOA_hist);
 TOA_RCP2_6_ens_std=std(TOA_RCP2_6);
 TOA_RCP4_5_ens_std=std(TOA_RCP4_5);
 
 ERF_hist_ens_std=std(ERF_hist);
 ERF_RCP2_6_ens_std=std(ERF_RCP2_6);
 ERF_RCP4_5_ens_std=std(ERF_RCP4_5);
 
 amoc26N_hist_ens_std=std(amoc26N_hist);
 amoc26N_RCP2_6_ens_std=std(amoc26N_RCP2_6);
 amoc26N_RCP4_5_ens_std=std(amoc26N_RCP4_5);
 
 SIA_NH_Sep_hist_ens_std=std(SIA_NH_Sep_hist);
 SIA_NH_Sep_RCP2_6_ens_std=std(SIA_NH_Sep_RCP2_6);
 SIA_NH_Sep_RCP4_5_ens_std=std(SIA_NH_Sep_RCP4_5);
 
 SIA_NH_Mar_hist_ens_std=std(SIA_NH_Mar_hist);
 SIA_NH_Mar_RCP2_6_ens_std=std(SIA_NH_Mar_RCP2_6);
 SIA_NH_Mar_RCP4_5_ens_std=std(SIA_NH_Mar_RCP4_5);
 
 OHC_2000_hist_ens_std=std(OHC_2000_hist);
 OHC_2000_RCP2_6_ens_std=std(OHC_2000_RCP2_6);
 OHC_2000_RCP4_5_ens_std=std(OHC_2000_RCP4_5);
 
% 5-95% range (theoretically assuming normality; empirical):
 GMST_hist_range_90_theory=GMST_hist_ens_std*2*1.645;
 GMST_hist_sort=sort(GMST_hist);
 GMST_hist_range_90=GMST_hist_sort(95,:)-GMST_hist_sort(5,:);

 
 GMST_RCP2_6_range_90_theory=GMST_RCP2_6_ens_std*2*1.645;
 GMST_RCP2_6_sort=sort(GMST_RCP2_6);
 GMST_RCP2_6_range_90=GMST_RCP2_6_sort(95,:)-GMST_RCP2_6_sort(5,:);


 
% Define anomalies about ensemble mean. 19 July 2016: never used. 11 July
% 2017:  But the one that MIGHT be useful wasn't constructed....

%  GMST_hist_anom = GMST_hist-one_ens_size*GMST_hist_ens_mean;
%  GMST_RCP4_5_anom = GMST_RCP4_5-one_ens_size*GMST_RCP4_5_ens_mean;
%  GMST_RCP2_6_anom = GMST_RCP2_6-one_ens_size*GMST_RCP2_6_ens_mean;
% 
%  TOA_hist_anom = TOA_hist-one_ens_size*TOA_hist_ens_mean;
%  TOA_RCP4_5_anom = TOA_RCP4_5-one_ens_size*TOA_RCP4_5_ens_mean;
%  TOA_RCP2_6_anom = TOA_RCP2_6-one_ens_size*TOA_RCP2_6_ens_mean;
% 
%  ERF_hist_anom = ERF_hist-one_ens_size*ERF_hist_ens_mean;
%  ERF_RCP4_5_anom = ERF_RCP4_5-one_ens_size*ERF_RCP4_5_ens_mean;
%  ERF_RCP2_6_anom = ERF_RCP2_6-one_ens_size*ERF_RCP2_6_ens_mean;
% 
%  amoc26N_hist_anom = amoc26N_hist-one_ens_size*amoc26N_hist_ens_mean;
%  amoc26N_RCP4_5_anom = amoc26N_RCP4_5-one_ens_size*amoc26N_RCP4_5_ens_mean;
%  amoc26N_RCP2_6_anom = amoc26N_RCP2_6-one_ens_size*amoc26N_RCP2_6_ens_mean;
% 
%  SIA_NH_Sep_hist_anom = SIA_NH_Sep_hist-one_ens_size*SIA_NH_Sep_hist_ens_mean;
%  SIA_NH_Sep_RCP4_5_anom = SIA_NH_Sep_RCP4_5-one_ens_size*SIA_NH_Sep_RCP4_5_ens_mean;
%  SIA_NH_Sep_RCP2_6_anom = SIA_NH_Sep_RCP2_6-one_ens_size*SIA_NH_Sep_RCP2_6_ens_mean;
% 
%  SIA_NH_Mar_hist_anom = SIA_NH_Mar_hist-one_ens_size*SIA_NH_Mar_hist_ens_mean;
%  SIA_NH_Mar_RCP4_5_anom = SIA_NH_Mar_RCP4_5-one_ens_size*SIA_NH_Mar_RCP4_5_ens_mean;
%  SIA_NH_Mar_RCP2_6_anom = SIA_NH_Mar_RCP2_6-one_ens_size*SIA_NH_Mar_RCP2_6_ens_mean;

 OHC_2000_hist_anom = OHC_2000_hist-one_ens_size*OHC_2000_hist_ens_mean;
 OHC_2000_RCP4_5_anom = OHC_2000_RCP4_5-one_ens_size*OHC_2000_RCP4_5_ens_mean;
 OHC_2000_RCP2_6_anom = OHC_2000_RCP2_6-one_ens_size*OHC_2000_RCP2_6_ens_mean;

%  check=mean(GMST_hist_anom);

%% Plot stuff

 figure(1), clf reset
%  orient landscape
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 
 subplot(3,1,1)
 plot([year_hist year_RCP4_5] ,[GMST_hist GMST_RCP4_5]')
 hold on
 hl=plot(year_hist,GMST_hist_ens_mean, 'k',...
     year_RCP4_5,GMST_RCP4_5_ens_mean','r',...
     year_RCP2_6, GMST_RCP2_6_ens_mean','b','linewidth',2);
 legend(hl,'historical','RCP4.5','RCP2.6','location','northwest')

 title('GMST anomaly, historical & RCP4.5')
 xlabel('Year')
 ylabel('K')
 axis([1850 2035 -1 2])
 
 subplot(3,1,2)
 plot([year_hist year_RCP4_5],[TOA_hist TOA_RCP4_5]')
 hold on
%  plot([year_hist year_RCP4_5],[ERF_hist_ens_mean ERF_RCP4_5_ens_mean]','r','linewidth',2)
 hl=plot(year_hist,ERF_hist_ens_mean, 'k',...
     year_RCP4_5,ERF_RCP4_5_ens_mean','r',...
     year_RCP2_6, ERF_RCP2_6_ens_mean','b','linewidth',2);
 legend(hl,'ERF historical','ERF RCP4.5','ERF RCP2.6','location','southeast')

 title('TOA downward anomaly, historical & RCP4.5')
 xlabel('Year')
 ylabel('Wm^{-2}')
 axis([1850 2035 -3 3])
 
 subplot(3,1,3)
 plot([year_hist year_RCP4_5],[ERF_hist ERF_RCP4_5]')
 hold on
%  plot([year_hist year_RCP4_5],[ERF_hist_ens_mean ERF_RCP4_5_ens_mean]','r','linewidth',2)
%  plot([year_RCP2_6],[ERF_RCP2_6_ens_mean]','b','linewidth',2)
 hl=plot(year_hist,ERF_hist_ens_mean, 'k',...
     year_RCP4_5,ERF_RCP4_5_ens_mean','r',...
     year_RCP2_6, ERF_RCP2_6_ens_mean','b','linewidth',2);
 legend(hl,'ERF historical','ERF RCP4.5','ERF RCP2.6','location','southeast')

 line([1850 2035], [0 0],'color','k','linestyle',':')
 title('ERF, historical & RCP4.5')
 xlabel('Year')
 ylabel('Wm^{-2}')
 axis([1850 2035 -3 3])
 
 print ('GMST_TOA_ERF_1850_2035.pdf','-dpdf')

%% Focus on GMST

 figure(2), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);

 start_year=1850;
 isy=find(year_hist==start_year);
 ymin=-0.5; ymax=1.8;
 fs=14;    % Text fontsize
 
 subplot(2,1,1)

 plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist(:,isy:end), GMST_RCP4_5]')
 hold on
 h1=plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP4_5_ens_mean]','k',year_RCP2_6, GMST_RCP2_6_ens_mean','b',...
     year_RCP4_5,GMST_RCP4_5_ens_mean','r','linewidth',2);
 h2=plot(GMST_obs_years,GMST_obs_adj,'color',[33 143 118]./255,'linewidth',3);
 legend([h1; h2],'historical','RCP2.6','RCP4.5','HadCRUT4','location','northwest')
 
 title('GMST anomaly, historical & RCP4.5','fontsize',fs)
 xlabel('Year','fontsize',fs)
 ylabel('K','fontsize',fs)
 axis([start_year 2035 ymin ymax])
 set(gca,'fontsize',fs)
 
 subplot(2,1,2)
 plot([year_hist(isy:end), year_RCP2_6] ,[GMST_hist(:,isy:end), GMST_RCP2_6]')
 hold on
 h1=plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP4_5_ens_mean]','k',year_RCP2_6, GMST_RCP2_6_ens_mean','r',...
     year_RCP4_5,GMST_RCP4_5_ens_mean','b','linewidth',2);
 h2=plot(GMST_obs_years,GMST_obs_adj,'color',[33 143 118]./255,'linewidth',3);
 legend([h1; h2],'historical','RCP2.6','RCP4.5','HadCRUT4','location','northwest')
  
 title('GMST anomaly, historical & RCP2.6','fontsize',fs)
 xlabel('Year','fontsize',fs)
 ylabel('K','fontsize',fs)
 axis([start_year 2035 ymin ymax])
 set(gca,'fontsize',fs)

 print ('GMST_1850_2035.pdf','-dpdf')

%% Some parts for talk. First GMST time series, RCP2.6 and RCP4.5, with 
% means of both ensembles and the observations.

 figure(3), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 4 27 12]);
 
 start_year=2005;
 isy=find(year_hist==start_year);
 lw=5;      % Common linewidth
 
 tag_rcp=0      % Choose scenario:  1: RCP2.6, 0: RCP4.5
 
 if tag_rcp==1      % RCP2.6

 plot([year_hist(isy:end), year_RCP2_6] ,[GMST_hist(:,isy:end), GMST_RCP2_6]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP4_5_ens_mean]','r','linewidth',lw)
 hl=plot(year_RCP2_6, GMST_RCP2_6_ens_mean','b',...
     year_RCP4_5,GMST_RCP4_5_ens_mean','r','linewidth',lw);

 h2=plot(GMST_obs_years(isy:end),GMST_obs_adj(isy:end),'color',...
     [33 143 118]./255,'linewidth',lw);
 legend([hl;h2],'RCP2.6 ensemble mean','RCP4.5 ensemble mean','HadCRUT4',...
     'location','northwest')

 title('GMST anomaly, RCP2.6','fontsize',20)
 xlabel('Year','fontsize',20)
%  title('Temperaturnderung gg. 1861-1880, historisch und RCP2.6','fontsize',20)
%  xlabel('Jahr','fontsize',20)
 ylabel('K','fontsize',20)
 axis([start_year 2035 0.5 1.8])
%  axis([start_year 2035 -0.6 1.8])
 set(gca,'fontsize',20)
 print ('GMST_2005_2035_RCP2_6.pdf','-dpdf')
 
%  Quick fix to get RCP4.5: simply overwrite. I'm having trouble getting
%  the same nice aspect ratio with "subplot (2,1,1)"

 end 
 
 if tag_rcp==0      %  RCP4.5
     
 plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist(:,isy:end), GMST_RCP4_5]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[GMST_hist_ens_mean(isy:end), ...
     GMST_RCP4_5_ens_mean]','r','linewidth',lw)
 hl=plot(year_RCP2_6, GMST_RCP2_6_ens_mean','b',...
     year_RCP4_5,GMST_RCP4_5_ens_mean','r','linewidth',lw);
 h2=plot(GMST_obs_years(isy:end),GMST_obs_adj(isy:end),'color',...
     [33 143 118]./255,'linewidth',lw);
 legend([hl;h2],'RCP2.6 ensemble mean','RCP4.5 ensemble mean','HadCRUT4',...
     'location','northwest')
 
 title('GMST anomaly, RCP4.5','fontsize',20)
 xlabel('Year','fontsize',20)
%  title('Temperaturnderung gg. 1861-1880, historisch und RCP2.6','fontsize',20)
%  xlabel('Jahr','fontsize',20)
 ylabel('K','fontsize',20)
 axis([start_year 2035 0.5 1.8])
%  axis([start_year 2035 -0.6 1.8])
 set(gca,'fontsize',20)
 print ('GMST_2005_2035_RCP4_5.pdf','-dpdf')

 end


%% GMST trend calculation for RCP2.6

% Observed trend, 2001:2015:
 GMST_obs_trend_raw=polyfit([2001:2015], GMST_obs(152:166)',1);
 GMST_obs_trend=10*GMST_obs_trend_raw(1);
 
 trend_2020_RCP2_6=zeros(100,2); trend_2035_RCP2_6=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:1:2020],GMST_RCP2_6(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=10*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:1:2035],GMST_RCP2_6(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=10*trend_2035_RCP2_6(ir,1);
 end

 figure(4), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperPosition', [.5 8 27 8]);
 
 binranges=[-1:.025:1];
 xmin=-.25; xmax=.65; ymin=0; ymax=15.5;

 subplot(1,3,1)
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 hl=line([GMST_obs_trend GMST_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed, 2001-2015');
 axis([xmin xmax ymin ymax])
 title('GMST trend 2006-2020, RCP2.6')
 xlabel('K per decade')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2021-2035')
 xlabel('K per decade')
 
 subplot(1,3,3)
 xmin=-.45; xmax=.45;
 trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change, 2035 vs. 2020')
 xlabel('K per decade')

% Sort trends and output various counts: 
 trend_diff_sort=sort(trend_diff);
 ifast_GMST_RCP2_6=find(trend_diff_sort>0,1,'first')
 
 trend_2020_RCP2_6_sort=sort(trend_2020_RCP2_6(:,1));
 
% Compute 5-95% range:
 GMST_trend_2020_RCP2_6_5_95=...
     [trend_2020_RCP2_6_sort(5), trend_2020_RCP2_6_sort(95)]
 
 trend_2035_RCP2_6_sort=sort(trend_2035_RCP2_6(:,1));
 GMST_trend_2035_RCP2_6_5_95=...
     [trend_2035_RCP2_6_sort(5), trend_2035_RCP2_6_sort(95)]
 
 print ('GMST_trends_2020_2035_RCP2_6.pdf','-dpdf')

%% Only histogram of trend differences, RCP2.6

 figure(5), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 2.5 27 15]);
 

%  trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
%  trend_diff_sort=sort(trend_diff);
%  ifast=find(trend_diff_sort>0,1,'first')
%  
 binranges=[-1:.025:1];
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([-.45 .45 0 10.5])
 title('Change in GMST trend, 2035 vs. 2020, RCP2.6','fontsize',28)
%  title('nderung im Temperaturtrend, 2035 vs. 2020','fontsize',28)
 xlabel('K per decade','fontsize',28)
 set(gca,'fontsize',28)

 print ('GMST_trends_2035_vs_2020_RCP2_6.pdf','-dpdf') 
%% Now GMST trend calculation for RCP4.5

 trend_2020_RCP4_5=zeros(100,2); trend_2035_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:1:2020],GMST_RCP4_5(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=10*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:1:2035],GMST_RCP4_5(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=10*trend_2035_RCP4_5(ir,1);
 end


 figure(6), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperPosition', [.5 8 27 8]);

 binranges=[-1:.025:1];
 xmin=-.25; xmax=.65; ymin=0; ymax=15.5;
 
 subplot(1,3,1)
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
            % Plot before obs line, because otherwise dotted gets included
            % in legend -- puzzling. 
 h2=line([GMST_obs_trend GMST_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(h2,'Observed, 2001-2015');
 axis([xmin xmax ymin ymax])
 title('GMST trend 2006-2020, RCP4.5')
 xlabel('K per decade')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2021-2035')
 xlabel('K per decade')
 
 subplot(1,3,3)
 xmin=-.45; xmax=.45; 
 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change, 2035 vs. 2020')
 xlabel('K per decade')

% Sort trends and output various counts: 
 trend_diff_sort=sort(trend_diff);
 ifast_GMST_RCP4_5=find(trend_diff_sort>0,1,'first')
 
 trend_2020_RCP4_5_sort=sort(trend_2020_RCP4_5(:,1));
 
% Compute 5-95% range
 GMST_trend_2020_RCP4_5_5_95=...
     [trend_2020_RCP4_5_sort(5), trend_2020_RCP4_5_sort(95)]
 
 trend_2035_RCP4_5_sort=sort(trend_2035_RCP4_5(:,1));
 GMST_trend_2035_RCP4_5_5_95=...
     [trend_2035_RCP4_5_sort(5), trend_2035_RCP4_5_sort(95)]
 
 print ('GMST_trends_2020_2035_RCP4_5.pdf','-dpdf')

%% Only histogram of trend differences, RCP4.5

 figure(7), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 2.5 27 15]);
 

 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trend_diff_sort=sort(trend_diff);
 ifast=find(trend_diff_sort>0,1,'first')
 
 binranges=[-1:.05:1];
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([-.6 .6 0 15.5])
 title('Change in GMST trend, 2035 vs. 2020, RCP4.5','fontsize',28)
%  title('nderung im Temperaturtrend, 2035 vs. 2020','fontsize',28)
 xlabel('K','fontsize',28)
 set(gca,'fontsize',28)

 print ('GMST_trends_2035_vs_2020_RCP4_5.pdf', '-dpdf') 
 
%%
%  figure (8), clf reset
%  plot([year_hist year_RCP4_5] ,[GMST_hist_std GMST_RCP4_5_std]')
%  set(gcf, 'PaperOrientation', 'landscape')
%  set(gcf, 'PaperPosition', [.5 .5 27 19]);
%  title('GMST ensemble standard deviation, historical & RCP4.5')
%  xlabel('Year')
%  ylabel('K')
%  axis([1850 2035 0.08 0.16])
%  

%% Plot AMOC

 figure(9), clf reset
%  orient landscape
%  set(gcf, 'PaperOrientation', 'landscape')
%  set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperOrientation', 'portrait')
 set(gcf, 'PaperPosition', [.5 .5 19 27]);
%  12 October 2018: It seems to make a difference for the pdf whether the
%  matlab figure file is partial-screen or full-screen (!!!!!!!!!!!!!!!!!).
%  For the paper I prefer the partial-screen version. 

 xmin=2005; xmax=2035; ymin=12;ymax=25;   % axis limits
 isy=find(year_hist==xmin);
 lw=5;      % Common linewidth
 
 subplot(2,1,1)
 plot([year_hist year_RCP4_5] ,[amoc26N_hist amoc26N_RCP4_5]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[amoc26N_hist_ens_mean(isy:end), ...
     amoc26N_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[amoc26N_hist_ens_mean(isy:end), ...
    amoc26N_RCP4_5_ens_mean]','r','linewidth',lw)

 h1=plot(year_RCP2_6,amoc26N_RCP2_6_ens_mean','b',...
     year_RCP4_5, amoc26N_RCP4_5_ens_mean','r',...
     'linewidth',lw);
 h2=plot(AMOC_obs_years,AMOC_obs,'color',[33 143 118]./255,'linewidth',lw);
%  legend([h1; h2],'historical','RCP2.6','RCP4.5','RAPID','location','northeast')
 legend([h1; h2],'RCP2.6, ensemble mean','RCP4.5, ensemble mean',...
     'Observed (RAPID)','location','northeast')

 title('AMOC at 26N, RCP4.5')
 xlabel('Year')
 ylabel('Sv')
 axis([xmin xmax ymin ymax])
 
 subplot(2,1,2)
 plot([year_hist year_RCP2_6] ,[amoc26N_hist amoc26N_RCP2_6]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[amoc26N_hist_ens_mean(isy:end), ...
     amoc26N_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[amoc26N_hist_ens_mean(isy:end), ...
    amoc26N_RCP4_5_ens_mean]','r','linewidth',lw)
 h1=plot(year_RCP2_6,amoc26N_RCP2_6_ens_mean','b',...
     year_RCP4_5, amoc26N_RCP4_5_ens_mean','r',...
     'linewidth',lw);

 h2=plot(AMOC_obs_years,AMOC_obs,'color',[33 143 118]./255,'linewidth',lw);
%  legend([h1; h2],'historical','RCP2.6','RCP4.5','RAPID','location','northeast')
 legend([h1; h2],'RCP2.6, ensemble mean','RCP4.5, ensemble mean',...
     'Observed (RAPID)','location','northeast')

 title('AMOC at 26N, RCP2.6')
 xlabel('Year')
 ylabel('Sv')
 axis([xmin xmax ymin ymax])
 
 print (['amoc26N_RCP2.6_RCP4.5_',num2str(xmin),'_',num2str(xmax),'.pdf'],'-dpdf')
 
%% Plot AMOC long

 figure(99), clf reset
%  orient landscape
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=1990; xmax=2099; ymin=12;ymax=25;   % axis limits
 
%  subplot(2,1,1)
 plot([year_hist year_RCP4_5_long] ,[amoc26N_hist amoc26N_RCP4_5_long]')
 hold on
 h1=plot(year_hist,amoc26N_hist_ens_mean, 'k',...
     year_RCP2_6_long,amoc26N_RCP2_6_long_ens_mean','b',...
     year_RCP4_5_long, amoc26N_RCP4_5_long_ens_mean','r',...
     'linewidth',2);
 h2=plot(AMOC_obs_years,AMOC_obs,'color',[33 143 118]./255,'linewidth',3);
 legend([h1; h2],'historical','RCP2.6','RCP4.5','RAPID','location','northeast')

 title('amoc26N, historical & RCP4.5')
 xlabel('Year')
 ylabel('Sv')
 axis([xmin xmax ymin ymax])
 
%  subplot(2,1,2)
%  plot([year_hist year_RCP2_6] ,[amoc26N_hist amoc26N_RCP2_6]')
%  hold on
%  h1=plot(year_hist,amoc26N_hist_ens_mean, 'k',...
%      year_RCP2_6,amoc26N_RCP2_6_ens_mean','b',...
%      year_RCP4_5, amoc26N_RCP4_5_ens_mean','r',...
%      'linewidth',2);
%  h2=plot(AMOC_obs_years,AMOC_obs,'color',[33 143 118]./255,'linewidth',3);
%  legend([h1; h2],'historical','RCP2.6','RCP4.5','RAPID','location','northeast')
% 
%  title('amoc26N, historical & RCP2.6')
%  xlabel('Year')
%  ylabel('Sv')
%  axis([xmin xmax ymin ymax])
 
 print (['amoc26N_RCP2.6_RCP4.5_',num2str(xmin),'_',num2str(xmax),'.pdf'],'-dpdf')
 
%% AMOC trend calculation for RCP2.6

 trend_2020_RCP2_6=zeros(100,2); trend_2035_RCP2_6=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:1:2020],amoc26N_RCP2_6(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=10*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:1:2035],amoc26N_RCP2_6(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=10*trend_2035_RCP2_6(ir,1);
 end

% Observed trend, whole length, separately for annual means and full
% record:
 AMOC_obs_trend_raw=polyfit(AMOC_obs_years, AMOC_obs,1);
 AMOC_obs_trend=10*AMOC_obs_trend_raw(1);
 
 MOC_mar_hc10_trend_raw=polyfit(JG,MOC_mar_hc10,1);
 MOC_mar_hc10_trend=3650*MOC_mar_hc10_trend_raw(1);
% I tend to trust the full record more!  Use it!

 figure(10), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=-4.; xmax=4.; ymin=0; ymax=32;

 subplot(1,3,1)
 binranges=[-4:.5:4];
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hold on
 hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'RAPID trend, 2004-2016');
 title('AMOC26N trend 2006-2020, RCP2.6')
 xlabel('Sv per decade')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
%  hold on
%  hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
%      [33 143 118]./255,'linewidth',3);
%  legend(hl,'RAPID trend, 2004-2016');
 title('AMOC26N trend 2021-2035, RCP2.6')
 title('2021-2035')
 xlabel('Sv per decade')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in AMOC26N trend, 2035 vs. 2020, RCP2.6')
 title('Change, 2035 vs. 2020')
 xlabel('Sv per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_AMOC26N_RCP2_6=find(trend_diff_sort>0,1,'first')
 
 print ('AMOC26N_trends_2020_2035_RCP2_6.pdf','-dpdf')
 
 AMOC_2016               % If desired -- Comparison for RAPID period

%% AMOC trend calculation for RCP4.5

 trend_2020_RCP4_5=zeros(100,2); trend_2035_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:1:2020],amoc26N_RCP4_5(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=10*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:1:2035],amoc26N_RCP4_5(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=10*trend_2035_RCP4_5(ir,1);
 end


 figure(11), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=-4.; xmax=4.; ymin=0; ymax=28;

 subplot(1,3,1)
 binranges=[-4:.5:4];
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'RAPID trend, 2004-2015');
 title('AMOC26N trend 2006-2020, RCP4.5')
 xlabel('Sv per decade')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
%  hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
%      [33 143 118]./255,'linewidth',3);
%  legend(hl,'RAPID trend, 2004-2015');
%  title('AMOC26N trend 2021-2035, RCP4.5')
 title('2021-2035')
 xlabel('Sv per decade')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in AMOC26N trend, 2035 vs. 2020, RCP4.5')
 title('Change, 2035 vs. 2020')
 xlabel('Sv per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_AMOC26N_RCP4_5=find(trend_diff_sort>0,1,'first')
 
 print ('AMOC26N_trends_2020_2035_RCP4_5.pdf','-dpdf')

%% Plot NH September sea-ice area

 figure(12), clf reset
%  orient landscape
 set(gcf, 'PaperOrientation', 'portrait')
 set(gcf, 'PaperPosition', [.5 .5 19 27]);
%  12 October 2018: It seems to make a difference for the pdf whether the
%  matlab figure file is partial-screen or full-screen (!!!!!!!!!!!!!!!!!).
%  For the paper I prefer the partial-screen version. 

 xmin=2005; xmax=2035; ymin=0;ymax=6;   % axis limits
 isy=find(year_hist,xmin);
 lw=5;      % Common linewidth
 
 subplot(2,1,1)
 plot([year_hist year_RCP4_5] ,[SIA_NH_Sep_hist SIA_NH_Sep_RCP4_5]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[SIA_NH_Sep_hist_ens_mean(isy:end), ...
     SIA_NH_Sep_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[SIA_NH_Sep_hist_ens_mean(isy:end), ...
    SIA_NH_Sep_RCP4_5_ens_mean]','r','linewidth',lw)
%  h1=plot(year_hist,SIA_NH_Sep_hist_ens_mean, 'k',...
%      year_RCP2_6,SIA_NH_Sep_RCP2_6_ens_mean','r',...
%      year_RCP4_5, SIA_NH_Sep_RCP4_5_ens_mean','b','linewidth',2);
 h1=plot(year_RCP2_6,SIA_NH_Sep_RCP2_6_ens_mean','b',...
     year_RCP4_5, SIA_NH_Sep_RCP4_5_ens_mean','r','linewidth',lw);
 h2=plot(SIA_obs_years,SIA_NH_Sep_obs,'color',[33 143 118]./255,'linewidth',lw);
%  legend([h1; h2],'historical','RCP2.6','RCP4.5','Observed','location','northeast')
 legend([h1; h2],'RCP2.6, ensemble mean','RCP4.5, ensemble mean',...
     'Observed','location','northeast')

 title('SIA NH Sep, RCP4.5')
 xlabel('Year')
 ylabel('Million km^2')
 axis([xmin xmax ymin ymax])
 
 subplot(2,1,2)
 plot([year_hist year_RCP2_6] ,[SIA_NH_Sep_hist SIA_NH_Sep_RCP2_6]')
 hold on
% Need to patch historical and scenarios to avoid gap for year 2005.  Make
% sure to create patch for both scenarios. After patch, re-draw for legend.
% 
 plot([year_hist(isy:end), year_RCP2_6] ,[SIA_NH_Sep_hist_ens_mean(isy:end), ...
     SIA_NH_Sep_RCP2_6_ens_mean]','b','linewidth',lw)
 plot([year_hist(isy:end), year_RCP4_5] ,[SIA_NH_Sep_hist_ens_mean(isy:end), ...
    SIA_NH_Sep_RCP4_5_ens_mean]','r','linewidth',lw)
%  h1=plot(year_hist,SIA_NH_Sep_hist_ens_mean, 'k',...
%      year_RCP2_6,SIA_NH_Sep_RCP2_6_ens_mean','b',...
%      year_RCP4_5, SIA_NH_Sep_RCP4_5_ens_mean','r','linewidth',2);
 h1=plot(year_RCP2_6,SIA_NH_Sep_RCP2_6_ens_mean','b',...
     year_RCP4_5, SIA_NH_Sep_RCP4_5_ens_mean','r','linewidth',lw);
 h2=plot(SIA_obs_years,SIA_NH_Sep_obs,'color',[33 143 118]./255,'linewidth',lw);
%  legend([h1; h2],'historical','RCP2.6','RCP4.5','Observed','location','northeast')
 legend([h1; h2],'RCP2.6, ensemble mean','RCP4.5, ensemble mean',...
     'Observed','location','northeast')

 title('SIA NH Sep, RCP2.6')
 xlabel('Year')
 ylabel('Million km^2')
 axis([xmin xmax ymin ymax])
 
 print (['SIA_NH_Sep_RCP2.6_RCP4.5_',num2str(xmin),'_',num2str(xmax),'.pdf'],'-dpdf')
 
 %% NH September SIA trend calculation for RCP2.6

% Observed trend, 2001:2015:
 SIA_NH_Sep_obs_trend_raw=polyfit([2001:2015], SIA_NH_Sep_obs(end-14:end),1);
 SIA_NH_Sep_obs_trend=15*SIA_NH_Sep_obs_trend_raw(1);
 
 trend_2020_RCP2_6=zeros(100,2); trend_2035_RCP2_6=zeros(100,2); % Pre-allocate
 
% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:1:2020],SIA_NH_Sep_RCP2_6(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=15*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:1:2035],SIA_NH_Sep_RCP2_6(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=15*trend_2035_RCP2_6(ir,1);
 end


 figure(13), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 
 xmin=-3.5; xmax=3.5; ymin=0;ymax=25;   % axis limits

 subplot(1,3,1)
 binranges=[-4:.25:4];
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Sep_obs_trend SIA_NH_Sep_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Sep trend 2006-2020, RCP2.6')
 xlabel('Million km^2')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Sep_obs_trend SIA_NH_Sep_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Sep trend 2021-2035, RCP2.6')
 title('2021-2035')
 xlabel('Million km^2')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in SIA NH Sep trend, 2035 vs. 2020, RCP2.6')
 title('Change, 2035 vs. 2020')
 xlabel('Million km^2')

 trend_diff_sort=sort(trend_diff);
 ifast_SIA_NH_Sep_RCP2_6=find(trend_diff_sort>0,1,'first')
 
 print ('SIA_NH_Sep_trends_2020_2035_RCP2_6.pdf','-dpdf')

 %% NH September SIA trend calculation for RCP4.5

 trend_2020_RCP4_5=zeros(100,2); trend_2035_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:1:2020],SIA_NH_Sep_RCP4_5(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=15*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:1:2035],SIA_NH_Sep_RCP4_5(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=15*trend_2035_RCP4_5(ir,1);
 end


 figure(14), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=-3.5; xmax=3.5; ymin=0;ymax=18;   % axis limits

 subplot(1,3,1)
 binranges=[-4:.25:4];
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Sep_obs_trend SIA_NH_Sep_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Sep trend 2006-2020, RCP4.5')
 xlabel('Million km^2')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Sep_obs_trend SIA_NH_Sep_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Sep trend 2021-2035, RCP2.6')
 title('2021-2035')
 xlabel('Million km^2')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in SIA NH Sep trend, 2035 vs. 2020, RCP4.5')
 title('Change, 2035 vs. 2020')
 xlabel('Million km^2')

 trend_diff_sort=sort(trend_diff);
 ifast_SIA_NH_Sep_RCP4_5=find(trend_diff_sort>0,1,'first')
 
 print ('SIA_NH_Sep_trends_2020_2035_RCP4_5.pdf','-dpdf')

%% Plot NH March sea-ice area

 figure(15), clf reset
%  orient landscape
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=1850; xmax=2035; ymin=10;ymax=17;   % axis limits
 
 subplot(2,1,1)
 plot([year_hist year_RCP4_5] ,[SIA_NH_Mar_hist SIA_NH_Mar_RCP4_5]')
 hold on
 h1=plot(year_hist,SIA_NH_Mar_hist_ens_mean, 'k',...
     year_RCP2_6,SIA_NH_Mar_RCP2_6_ens_mean','b',...
     year_RCP4_5, SIA_NH_Mar_RCP4_5_ens_mean','r','linewidth',2);
 h2=plot(SIA_obs_years,SIA_NH_Mar_obs,'color',[33 143 118]./255,'linewidth',3);
 legend([h1; h2],'historical','RCP2.6','RCP4.5','Observed','location','northeast')

 title('SIA NH Mar, historical & RCP4.5')
 xlabel('Year')
 ylabel('Million km^2')
 axis([xmin xmax ymin ymax])
 
 subplot(2,1,2)
 plot([year_hist year_RCP2_6] ,[SIA_NH_Mar_hist SIA_NH_Mar_RCP2_6]')
 hold on
 h1=plot(year_hist,SIA_NH_Mar_hist_ens_mean, 'k',...
     year_RCP2_6,SIA_NH_Mar_RCP2_6_ens_mean','b',...
     year_RCP4_5, SIA_NH_Mar_RCP4_5_ens_mean','r','linewidth',2);
 h2=plot(SIA_obs_years,SIA_NH_Mar_obs,'color',[33 143 118]./255,'linewidth',3);
 legend([h1; h2],'historical','RCP2.6','RCP4.5','Observed','location','northeast')

 title('SIA NH Mar, historical & RCP2.6')
 xlabel('Year')
 ylabel('Million km^2')
 axis([xmin xmax ymin ymax])
 
 print ('SIA_NH_Mar_RCP2.6_RCP4.5_1850_2035.pdf','-dpdf')
 
 %% NH March SIA trend calculation for RCP2.6

% Observed trend, 2001:2015:
 SIA_NH_Mar_obs_trend_raw=polyfit([2001:2015], SIA_NH_Mar_obs(end-14:end),1);
 SIA_NH_Mar_obs_trend=15*SIA_NH_Mar_obs_trend_raw(1);
 
 trend_2020_RCP2_6=zeros(100,2); trend_2035_RCP2_6=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:1:2020],SIA_NH_Mar_RCP2_6(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=15*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:1:2035],SIA_NH_Mar_RCP2_6(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=15*trend_2035_RCP2_6(ir,1);
 end


 figure(16), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 
 xmin=-2.5; xmax=2.5; ymin=0;ymax=25;   % axis limits

 subplot(1,3,1)
 binranges=[-4:.25:4];
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Mar_obs_trend SIA_NH_Mar_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Mar trend 2006-2020, RCP2.6')
 xlabel('Million km^2')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Mar_obs_trend SIA_NH_Mar_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Mar trend 2021-2035, RCP2.6')
 xlabel('Million km^2')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in SIA NH Mar trend, 2035 vs. 2020, RCP2.6')
 xlabel('Million km^2')

 trend_diff_sort=sort(trend_diff);
 ifast_SIA_NH_Mar_RCP2_6=find(trend_diff_sort>0,1,'first')
 
 print ('SIA_NH_Mar_trends_2020_2035_RCP2_6.pdf','-dpdf')

 %% NH March SIA trend calculation for RCP4.5

 trend_2020_RCP4_5=zeros(100,2); trend_2035_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:1:2020],SIA_NH_Mar_RCP4_5(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=15*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:1:2035],SIA_NH_Mar_RCP4_5(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=15*trend_2035_RCP4_5(ir,1);
 end


 figure(17), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=-2.5; xmax=2.5; ymin=0;ymax=25;   % axis limits

 subplot(1,3,1)
 binranges=[-4:.25:4];
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Mar_obs_trend SIA_NH_Mar_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Mar trend 2006-2020, RCP4.5')
 xlabel('Million km^2')
 
 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([SIA_NH_Mar_obs_trend SIA_NH_Mar_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2001-2015');
 title('SIA NH Mar trend 2021-2035, RCP2.6')
 xlabel('Million km^2')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('Change in SIA NH Mar trend, 2035 vs. 2020, RCP4.5')
 xlabel('Million km^2')

 trend_diff_sort=sort(trend_diff);
 ifast_SIA_NH_Mar_RCP4_5=find(trend_diff_sort>0,1,'first')
 
 print ('SIA_NH_Mar_trends_2020_2035_RCP4_5.pdf','-dpdf')

%% Plot heat content

 figure(18), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 
% Adjust observations to ensemble-mean of overlap period of pentadal record 
% with historical, 1955-2005.  Notice that the pentadal "timestamp" runs
% from 1957.5 to 2002.5. Because of these counting complications, it's best
% to insert limits of averaging by hand.
 OHC_2000_adjustment=...
     mean(OHC_2000_hist_ens_mean(106:end))-...  % 106: year 1955
     mean(OHC_2000_obs_pentadal(1:46));
 
 OHC_2000_obs_pentadal_adj = OHC_2000_obs_pentadal + OHC_2000_adjustment;
 OHC_2000_obs_adj = OHC_2000_obs + OHC_2000_adjustment;

 xmin=1950; xmax=2035; ymin=-0;ymax=72;   % axis limits
 
 subplot(2,1,1)
 plot([1850:2035] ,[OHC_2000_hist'; OHC_2000_RCP2_6'])
 hold on
 h1=plot(year_hist,OHC_2000_hist_ens_mean, 'k',...
     [2006:2035],OHC_2000_RCP2_6_ens_mean,'b',...
     [2006:2035],OHC_2000_RCP4_5_ens_mean,'r','linewidth',2);
 h2=plot(OHC_2000_obs_years,OHC_2000_obs_adj,'color',...
     [33 143 118]./255,'linewidth',3);
 h3=plot(OHC_2000_obs_years_pentadal,OHC_2000_obs_pentadal_adj,...
     'color',[33 143 118]./255,'linewidth',4,'linestyle',':');
 
 legend([h1; h2; h3],'historical','RCP2.6','RCP4.5','Observed','Obs. pentadal',...
     'location','northwest')

 title('OHC 2000, historical & RCP2.6')
 xlabel('Year')
 ylabel('10^{22} J')
 axis([xmin xmax ymin ymax])
  
 subplot(2,1,2)
 plot([1850:2035] ,[OHC_2000_hist'; OHC_2000_RCP4_5'])
 hold on
 h1=plot(year_hist,OHC_2000_hist_ens_mean, 'k',...
     [2006:2035],OHC_2000_RCP2_6_ens_mean,'b',...
     [2006:2035],OHC_2000_RCP4_5_ens_mean,'r','linewidth',2);
 h2=plot(OHC_2000_obs_years,OHC_2000_obs_adj,'color',...
     [33 143 118]./255,'linewidth',3);
 h3=plot(OHC_2000_obs_years_pentadal,OHC_2000_obs_pentadal_adj,...
     'color',[33 143 118]./255,'linewidth',4,'linestyle',':');
 
 legend([h1; h2; h3],'historical','RCP2.6','RCP4.5','Observed','Obs. pentadal',...
     'location','northwest')

 title('OHC 2000, historical & RCP4.5')
 xlabel('Year')
 ylabel('10^{22} J')
 axis([xmin xmax ymin ymax])
  
 print (['OHC_2000_RCP2.6_RCP4.5_',num2str(xmin),'_',num2str(xmax),'.pdf'],'-dpdf')
 
 %% OHC trend calculation for 1995-2005 and 2005-2015 (RCP4.5)
 
 % Observed trend, 2005:2015:
 OHC_2000_obs_trend_raw=polyfit([2005:2015], OHC_2000_obs',1);
 OHC_2000_obs_trend=length(OHC_2000_obs)*OHC_2000_obs_trend_raw(1);

 trend_2015_RCP4_5=zeros(100,2); % Pre-allocate
 trend_2005_hist=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2015_RCP4_5(ir,:)=polyfit([2005:2015],...
         [OHC_2000_hist(ir,end) OHC_2000_RCP4_5(ir,1:10)],1);
     trend_2015_RCP4_5(ir,1)=10*trend_2015_RCP4_5(ir,1);
     trend_2005_hist(ir,:)=polyfit([1995:2005],OHC_2000_hist(ir,end-10:end),1);
     trend_2005_hist(ir,1)=10*trend_2005_hist(ir,1);
 end


 figure(19), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=4.5; xmax=15.5; ymin=0;ymax=20;   % axis limits
 
 subplot(1,3,1)
 binranges=[-20:.5:20];
 trendcount_2005=histc(trend_2005_hist(:,1),binranges);
 hb=bar(binranges,trendcount_2005,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2005-2015');
 title('OHC 2000 trend 1995-2005, historical')
 xlabel('10^{22} J per decade')

 subplot(1,3,2)
 binranges=[-20:.5:20];
 trendcount_2015=histc(trend_2015_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2015,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
%  hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
%      [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2005-2015');
 title('OHC 2000 trend 2005-2015, RCP4.5')
 xlabel('10^{22} J per decade')
 
 subplot(1,3,3)
 trend_diff=trend_2015_RCP4_5-trend_2005_hist;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 xmin1=-5.5; xmax1=5.5; ymin1=0;ymax1=20;   % axis limits
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin1 xmax1 ymin1 ymax1])
 title('Change in OHC 2000 trend, 2015 vs. 2005, RCP4.5')
 xlabel('10^{22} J per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_OHC_2000_RCP4_5_early=find(trend_diff_sort>0,1,'first')
 
 print ('OHC_2000_trends_2005_2015_RCP4_5.pdf','-dpdf')

%% OHC trend calculation for 2006-2020 and 2021-2035 (RCP2.6)
 
 trend_2020_RCP2_6=zeros(100,2); % Pre-allocate
 trend_2035_RCP2_6=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:2020], OHC_2000_RCP2_6(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=10*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:2035], OHC_2000_RCP2_6(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=10*trend_2035_RCP2_6(ir,1);
 end

 figure(20), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 8 27 8]);
 xmin=5.5; xmax=16.5; ymin=0;ymax=30;   % axis limits
 
 subplot(1,3,1)
 binranges=[-20:.5:20];
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2005-2015');
 title('OHC 2000 trend 2006-2020, RCP2.6')
 xlabel('10^{22} J per decade')

 subplot(1,3,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
%  hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
%      [33 143 118]./255,'linewidth',3);
%  legend(hl,'Observed trend, 2005-2015');
 title('2021-2035')
 xlabel('10^{22} J per decade')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 xmin1=-5.5; xmax1=5.5; ymin1=ymin;ymax1=ymax;   % axis limits
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin1 xmax1 ymin1 ymax1])
 title('Change in OHC 2000 trend, 2035 vs. 2020, RCP2.6')
 title('Change, 2035 vs. 2020')
 xlabel('10^{22} J per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_OHC_2000_RCP2_6=find(trend_diff_sort>0,1,'first')
 
 print ('OHC_2000_trends_2020_2035_RCP2_6.pdf','-dpdf')

  %% OHC trend calculation for 2006-2020 and 2021-2035 (RCP4.5)
 
 trend_2020_RCP4_5=zeros(100,2); % Pre-allocate
 trend_2035_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:2020], OHC_2000_RCP4_5(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=10*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:2035], OHC_2000_RCP4_5(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=10*trend_2035_RCP4_5(ir,1);
 end

 figure(21), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 8 27 8]);
 xmin=5.5; xmax=16.5; ymin=0;ymax=30;   % axis limits
 
 subplot(1,3,1)
 binranges=[-20:.5:20];
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed trend, 2005-2015');
 title('OHC 2000 trend 2006-2020, RCP4.5')
 xlabel('10^{22} J per decade')

 subplot(1,3,2)
 binranges=[-20:.5:20];
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
%  hl=line([OHC_2000_obs_trend OHC_2000_obs_trend],[ymin ymax],'color',...
%      [33 143 118]./255,'linewidth',3);
%  legend(hl,'Observed trend, 2005-2015');
 title('2021-2035')
 xlabel('10^{22} J per decade')
 
 subplot(1,3,3)
 trend_diff=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff=histc(trend_diff(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 xmin1=-5.5; xmax1=5.5; ymin1=ymin;ymax1=ymax;   % axis limits
 hold on
 hl=line([0 0],[ymin1 ymax1],'color','k','linestyle',':'); 
 axis([xmin1 xmax1 ymin1 ymax1])
 title('Change, 2035 vs. 2020')
 xlabel('10^{22} J per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_OHC_2000_RCP4_5=find(trend_diff_sort>0,1,'first')
 
 print ('OHC_2000_trends_2020_2035_RCP4_5.pdf','-dpdf')

%% Now plot coherent differences between quantities, RCP4.5 minus RCP2.6.  
% Coherent means that any pair of simulations starts from the same state at
% the end of the historical period. 


 figure(22), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 xmin=2006; xmax=2035;  % axis limits
 lw1=4; lw2=3;  % Common linewidth
 
 subplot(2,2,1)
 plot(year_RCP4_5,GMST_RCP4_5'-GMST_RCP2_6')
 hold on
 h1=line([xmin xmax],[0 0],'color','k','linewidth',1);
 h2=plot(year_RCP4_5,mean(GMST_RCP4_5'-GMST_RCP2_6',2),'k','linewidth',lw1);
 h3=plot(year_RCP4_5,mean(GMST_RCP4_5'-GMST_RCP2_6',2)+...
     std(GMST_RCP4_5'-GMST_RCP2_6',0,2),'k:','linewidth',lw2);
 h4=plot(year_RCP4_5,mean(GMST_RCP4_5'-GMST_RCP2_6',2)-...
     std(GMST_RCP4_5'-GMST_RCP2_6',0,2),'k:','linewidth',lw2);
%  h5=plot(year_RCP4_5,mean(GMST_RCP4_5'-GMST_RCP2_6',2)+...
%      .1*std(GMST_RCP4_5'-GMST_RCP2_6',0,2),'k','linewidth',1);
%  h6=plot(year_RCP4_5,mean(GMST_RCP4_5'-GMST_RCP2_6',2)-...
%      .1*std(GMST_RCP4_5'-GMST_RCP2_6',0,2),'k','linewidth',1);
 ymin=-.7;ymax=.7;  axis([xmin xmax ymin ymax])
 xlabel('Year')
 ylabel('K')
 title('GMST, RCP4.5 minus RCP2.6')
 
 subplot(2,2,3)
 plot(year_RCP4_5,amoc26N_RCP4_5'-amoc26N_RCP2_6')
 hold on
 h1=line([xmin xmax],[0 0],'color','k','linewidth',1);
 h2=plot(year_RCP4_5,mean(amoc26N_RCP4_5'-amoc26N_RCP2_6',2),'k','linewidth',lw1);
 h3=plot(year_RCP4_5,mean(amoc26N_RCP4_5'-amoc26N_RCP2_6',2)+...
     std(amoc26N_RCP4_5'-amoc26N_RCP2_6',0,2),'k:','linewidth',lw2);
 h4=plot(year_RCP4_5,mean(amoc26N_RCP4_5'-amoc26N_RCP2_6',2)-...
     std(amoc26N_RCP4_5'-amoc26N_RCP2_6',0,2),'k:','linewidth',lw2);
%  h5=plot(year_RCP4_5,mean(amoc26N_RCP4_5'-amoc26N_RCP2_6',2)+...
%      .1*std(amoc26N_RCP4_5'-amoc26N_RCP2_6',0,2),'k','linewidth',1);
%  h6=plot(year_RCP4_5,mean(amoc26N_RCP4_5'-amoc26N_RCP2_6',2)-...
%      .1*std(amoc26N_RCP4_5'-amoc26N_RCP2_6',0,2),'k','linewidth',1);
 ymin = -4.5; ymax=4.5; axis([xmin xmax ymin ymax])
 xlabel('Year')
 ylabel('Sv')
 title('AMOC26N, RCP4.5 minus RCP2.6')
 
 subplot(2,2,2)
 plot(year_RCP4_5,SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6')
 hold on
 h1=line([xmin xmax],[0 0],'color','k','linewidth',1);
 h2=plot(year_RCP4_5,mean(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',...
     2),'k','linewidth',lw1);
 h3=plot(year_RCP4_5,mean(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',2)+...
     std(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',0,2),'k:','linewidth',lw2);
 h4=plot(year_RCP4_5,mean(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',2)-...
     std(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',0,2),'k:','linewidth',lw2);
%  h5=plot(year_RCP4_5,mean(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',2)+...
%      .1*std(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',0,2),'k','linewidth',1);
%  h6=plot(year_RCP4_5,mean(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',2)-...
%      .1*std(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',0,2),'k','linewidth',1);
 ymin = -2.5; ymax=2.5; axis([xmin xmax ymin ymax])
 xlabel('Year')
 ylabel('Million km^2')
 title('SIA NH Sep, RCP4.5 minus RCP2.6')
 
 subplot(2,2,4)
 plot(year_RCP4_5,OHC_2000_RCP4_5'-OHC_2000_RCP2_6')
 hold on
 h1=line([xmin xmax],[0 0],'color','k','linewidth',1);
 h2=plot(year_RCP4_5,mean(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',2),'k','linewidth',lw1);
 h3=plot(year_RCP4_5,mean(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',2)+...
     std(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',0,2),'k:','linewidth',lw2);
 h4=plot(year_RCP4_5,mean(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',2)-...
     std(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',0,2),'k:','linewidth',lw2);
%  h5=plot(year_RCP4_5,mean(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',2)+...
%      .1*std(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',0,2),'k','linewidth',1);
%  h6=plot(year_RCP4_5,mean(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',2)-...
%      .1*std(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',0,2),'k','linewidth',1);
 ymin = -4.5; ymax=4.5; axis([xmin xmax ymin ymax])
 xlabel('Year')
 ylabel('10^{22} J')
 title('OHC 2000, RCP4.5 minus RCP2.6')
 
 print ('All_indices_2006_2035_RCP4_5_minus_RCP2_6.pdf','-dpdf')

 
%% Plot time series of normalised ensemble standard deviation, to gauge time to 
% ensemble-spread saturation.  

 figure(23), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 10]);
 xmin=2006; xmax=2035;  ymin=0; ymax=1.25;   % axis limits
 
%  nstd_GMST=std(GMST_RCP4_5'-GMST_RCP2_6',0,2)-std(GMST_RCP4_5(end)-GMST_RCP2_6(end),0,2)
 std_GMST=std(GMST_RCP4_5'-GMST_RCP2_6',0,2);
 nstd_GMST=std_GMST/std_GMST(end);
%  nstd_GMST=std_GMST/mean(std_GMST(end-10:end));
 std_amoc26N=std(amoc26N_RCP4_5'-amoc26N_RCP2_6',0,2);
 nstd_amoc26N=std_amoc26N/std_amoc26N(end);
 std_SIA_NH_Sep=std(SIA_NH_Sep_RCP4_5'-SIA_NH_Sep_RCP2_6',0,2);
 nstd_SIA_NH_Sep=std_SIA_NH_Sep/std_SIA_NH_Sep(end);
 std_OHC_2000=std(OHC_2000_RCP4_5'-OHC_2000_RCP2_6',0,2);
 nstd_OHC_2000=std_OHC_2000/std_OHC_2000(end);
 
%  subplot(1,1,1)
 h1=plot(year_RCP4_5, nstd_GMST, year_RCP4_5, nstd_SIA_NH_Sep,  ...
     year_RCP4_5, nstd_amoc26N, year_RCP4_5, nstd_OHC_2000,'linewidth',2);
 hold on
 line([xmin xmax],[0.9 0.9],'color','k','linestyle',':','linewidth',1);
 legend(h1,'GMST', 'September Arctic SIA', 'AMOC at 26N', 'OHC_{2000}',...
     'location','southeast')
 axis([xmin xmax ymin ymax])
 xlabel('Year')
 title('Normalised ensemble standard deviation')

 print ('All_indices_2006_2035_RCP4_5_minus_RCP2_6_nstd.pdf','-dpdf')

%% Compute necessary and sufficient probabilities for causality:

% GMST:
 P0 = (ifast_GMST_RCP4_5 - 1)*0.01;
 P1 = (ifast_GMST_RCP2_6 - 1)*0.01;
 PN_GMST = 1 - P0/P1
 PS_GMST = (P1 - P0)/(1 - P0)
 PNS_GMST = P1 - P0
%
% AMOC 26N:
 P0 = 1 - (ifast_AMOC26N_RCP4_5 - 1)*0.01;      % Slowdown under forcing!
 P1 = 1 - (ifast_AMOC26N_RCP2_6 - 1)*0.01;
 PN_AMOC26N = 1 - P0/P1
 PS_AMOC26N = (P1 - P0)/(1 - P0)
 PNS_AMOC26N = P1 - P0
%
% SIA NH Sep:
 P0 = 1 - (ifast_SIA_NH_Sep_RCP4_5 - 1)*0.01;
 P1 = 1 - (ifast_SIA_NH_Sep_RCP2_6 - 1)*0.01;
 PN_SIA_NH_Sep = 1 - P0/P1
 PS_SIA_NH_Sep =  (P1 - P0)/(1 - P0)
 PNS_SIA_NH_Sep = P1 - P0
%
% OHC_2000:
 P0 = (ifast_OHC_2000_RCP4_5 - 1)*0.01;
 P1 = (ifast_OHC_2000_RCP2_6 - 1)*0.01;
 PN_OHC_2000 = 1 - P0/P1
 PS_OHC_2000 =  (P1 - P0)/(1 - P0)
 PNS_OHC_2000 = P1 - P0
%

%% Compute GMST change between 2016-2035 and 1986-2005, for comparison 
% against Ch11 asssessment (p. 1010). 
 
 start_year1=1986;
 end_year1=2005;
 start_year2=2016;
 end_year2=2035;
 isy1=find(year_hist==start_year1);
 iey1=find(year_hist==end_year1);
 isy2=find(year_RCP2_6==start_year2);
 iey2=find(year_RCP2_6==end_year2);
 
 GMST_mean_period1=mean(GMST_hist(:,isy1:iey1),2);
 GMST_mean_period2_RCP2_6=mean(GMST_RCP2_6(:,isy2:iey2),2);
 GMST_mean_period2_RCP4_5=mean(GMST_RCP4_5(:,isy2:iey2),2);
 GMST_mean_diff_RCP2_6=GMST_mean_period2_RCP2_6-GMST_mean_period1;
 GMST_mean_diff_sort_RCP2_6=sort(GMST_mean_diff_RCP2_6);
 GMST_mean_diff_RCP4_5=GMST_mean_period2_RCP4_5-GMST_mean_period1;
 GMST_mean_diff_sort_RCP4_5=sort(GMST_mean_diff_RCP4_5);
 
 disp('GMST_mean_diff_sort_RCP2_6 at 5%, 95%, 16%, 83%') 
 disp([GMST_mean_diff_sort_RCP2_6(5),GMST_mean_diff_sort_RCP2_6(95),...
     GMST_mean_diff_sort_RCP2_6(16),GMST_mean_diff_sort_RCP2_6(83)])

 disp('GMST_mean_diff_sort_RCP4_5 at 5%, 95%, 16%, 83%') 
 disp([GMST_mean_diff_sort_RCP4_5(5),GMST_mean_diff_sort_RCP4_5(95),...
     GMST_mean_diff_sort_RCP4_5(16),GMST_mean_diff_sort_RCP4_5(83)])

%  plot([year_hist(isy:end), year_RCP2_6] ,[GMST_hist(:,isy:end), GMST_RCP2_6]')
 


%%
% Compare diagnosed ERF against Thorsten's RFMIP-style ERF:
 forcing1=ncread('forcing_1.nc','f');
 years1=ncread('forcing_1.nc','time');
 forcing1=squeeze(forcing1);  
 years1=floor(years1*1.e-4);

 forcing2=ncread('forcing_2.nc','f');
 years2=ncread('forcing_2.nc','time');
 forcing2=squeeze(forcing2);  
 years2=floor(years2*1.e-4);
 
 forcing3=ncread('forcing_3.nc','f');
 years3=ncread('forcing_3.nc','time');
 forcing3=squeeze(forcing3);  
 years3=floor(years3*1.e-4);

 figure(24), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 
%  plot(years1,forcing1)
 h1=plot(years1,forcing1,years2,forcing2,years3,forcing3,...
     year_hist,ERF_hist_ens_mean,'linewidth',2);
 legend(h1,'forcing1','forcing2','forcing3','Forster method','location','northwest');
 xmin=1850; xmax=2005; ymin=-.7;ymax=.7;   % axis limits
 line([xmin xmax], [0 0],'color','k','linestyle',':')
 title('ERF, historical')
 xlabel('Year')
 ylabel('Wm^{-2}')
 axis([xmin xmax -3.5 2.5])
 
 print ('ERF_comparison.pdf','-dpdf')
 
%% Now start on comparison for the mid-term (2036-2050)
%  To be on the safe side, compute also for near-term, since the
%  simulations for the entire century were re-created completely at DKRZ. 

% GMST trend calculation for RCP2.6

 trend_2020_RCP2_6=zeros(100,2); trend_2035_RCP2_6=zeros(100,2); ...
     trend_2050_RCP2_6=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP2_6(ir,:)=polyfit([2006:1:2020],GMST_RCP2_6_long(ir,1:15),1);
     trend_2020_RCP2_6(ir,1)=10*trend_2020_RCP2_6(ir,1);
     trend_2035_RCP2_6(ir,:)=polyfit([2021:1:2035],GMST_RCP2_6_long(ir,16:30),1);
     trend_2035_RCP2_6(ir,1)=10*trend_2035_RCP2_6(ir,1);
     trend_2050_RCP2_6(ir,:)=polyfit([2036:1:2050],GMST_RCP2_6_long(ir,31:45),1);
     trend_2050_RCP2_6(ir,1)=10*trend_2050_RCP2_6(ir,1);
 end

 figure(25), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperPosition', [.5 8 27 8]);
 
 binranges=[-1:.025:1];
 xmin=-.25; xmax=.65; ymin=0; ymax=15.5;

 subplot(1,5,1)
 trendcount_2020=histc(trend_2020_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 hl=line([GMST_obs_trend GMST_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'Observed, 2001-2015');
 axis([xmin xmax ymin ymax])
 title('GMST trend 2006-2020, RCP2.6')
 xlabel('K per decade')
 
 subplot(1,5,2)
 trendcount_2035=histc(trend_2035_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2021-2035')
 xlabel('K per decade')
 
 
 subplot(1,5,3)
 trendcount_2050=histc(trend_2050_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2050,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2036-2050')
 xlabel('K per decade')
 
 subplot(1,5,4)
 xmin=-.45; xmax=.45;
 trend_diff_2035=trend_2035_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff_2035=histc(trend_diff_2035(:,1),binranges);
 hb=bar(binranges,trendcount_diff_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2035 vs. 2020')
 xlabel('K per decade')
 
 subplot(1,5,5)
 xmin=-.45; xmax=.45;
 trend_diff_2050=trend_2050_RCP2_6-trend_2020_RCP2_6;
 trendcount_diff_2050=histc(trend_diff_2050(:,1),binranges);
 hb=bar(binranges,trendcount_diff_2050,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2050 vs. 2020')
 xlabel('K per decade')

% Sort trends and output various counts: 
 trend_diff_2035_sort=sort(trend_diff_2035);
 ifast_2035_GMST_RCP2_6=find(trend_diff_2035_sort>0,1,'first')
 
 trend_diff_2050_sort=sort(trend_diff_2050);
 ifast_2050_GMST_RCP2_6=find(trend_diff_2050_sort>0,1,'first')
 
 trend_2020_RCP2_6_sort=sort(trend_2020_RCP2_6(:,1));
 
% Compute 5-95% range:
 GMST_trend_2020_RCP2_6_5_95=...
     [trend_2020_RCP2_6_sort(5), trend_2020_RCP2_6_sort(95)]
 
 trend_2035_RCP2_6_sort=sort(trend_2035_RCP2_6(:,1));
 GMST_trend_2035_RCP2_6_5_95=...
     [trend_2035_RCP2_6_sort(5), trend_2035_RCP2_6_sort(95)]
 
 trend_2050_RCP2_6_sort=sort(trend_2050_RCP2_6(:,1));
 GMST_trend_2050_RCP2_6_5_95=...
     [trend_2050_RCP2_6_sort(5), trend_2050_RCP2_6_sort(95)]
 
 print ('GMST_trends_2020_2035_2050_RCP2_6.pdf','-dpdf')

%% Only histogram of trend differences, RCP2.6

 figure(26), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 2.5 27 15]);
 

 binranges=[-1:.025:1];
 trendcount_diff=histc(trend_diff_2050(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([-.45 .45 0 12.5])
 title('Change in GMST trend, 2050 vs. 2020, RCP2.6','fontsize',28)
%  title('nderung im Temperaturtrend, 2035 vs. 2020','fontsize',28)
 xlabel('K per decade','fontsize',28)
 set(gca,'fontsize',28)

 print  ('GMST_trends_2050_vs_2020_RCP2_6.pdf', '-dpdf')
%  print  ('\\cifs.isi3.mpimet.mpg.de\mpi-office\oes\sync\Documents\papers\single\Attribution_Variability\m-files_VarAtt\GMST_trends_2050_vs_2020_RCP2_6.pdf', '-dpdf')
 
%% Now GMST trend calculation for RCP4.5

 trend_2020_RCP4_5=zeros(100,2); trend_2035_RCP4_5=zeros(100,2);...
     trend_2050_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2020_RCP4_5(ir,:)=polyfit([2006:1:2020],GMST_RCP4_5_long(ir,1:15),1);
     trend_2020_RCP4_5(ir,1)=10*trend_2020_RCP4_5(ir,1);
     trend_2035_RCP4_5(ir,:)=polyfit([2021:1:2035],GMST_RCP4_5_long(ir,16:30),1);
     trend_2035_RCP4_5(ir,1)=10*trend_2035_RCP4_5(ir,1);
     trend_2050_RCP4_5(ir,:)=polyfit([2036:1:2050],GMST_RCP4_5_long(ir,31:45),1);
     trend_2050_RCP4_5(ir,1)=10*trend_2050_RCP4_5(ir,1);
 end


 figure(27), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperPosition', [.5 8 27 8]);

 binranges=[-1:.025:1];
 xmin=-.25; xmax=.65; ymin=0; ymax=15.5;
 
 subplot(1,5,1)
 trendcount_2020=histc(trend_2020_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2020,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
            % Plot before obs line, because otherwise dotted gets included
            % in legend -- puzzling. 
 h2=line([GMST_obs_trend GMST_obs_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(h2,'Observed, 2001-2015');
 axis([xmin xmax ymin ymax])
 title('GMST trend 2006-2020, RCP4.5')
 xlabel('K per decade')
 
 subplot(1,5,2)
 trendcount_2035=histc(trend_2035_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2021-2035')
 xlabel('K per decade')
 
 subplot(1,5,3)
 trendcount_2050=histc(trend_2050_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2050,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2036-2050')
 xlabel('K per decade')
 
 subplot(1,5,4)
 xmin=-.45; xmax=.45;
 trend_diff_2035=trend_2035_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff_2035=histc(trend_diff_2035(:,1),binranges);
 hb=bar(binranges,trendcount_diff_2035,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2035 vs. 2020')
 xlabel('K per decade')
 
 subplot(1,5,5)
 xmin=-.45; xmax=.45; 
 trend_diff_2050=trend_2050_RCP4_5-trend_2020_RCP4_5;
 trendcount_diff_2050=histc(trend_diff_2050(:,1),binranges);
 hb=bar(binranges,trendcount_diff_2050,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([xmin xmax ymin ymax])
 title('2050 vs. 2020')
 xlabel('K per decade')

% Sort trends and output various counts: 
 trend_diff_2035_sort=sort(trend_diff_2035);
 ifast_2035_GMST_RCP4_5=find(trend_diff_2035_sort>0,1,'first')
 
 trend_diff_2050_sort=sort(trend_diff_2050);
 ifast_2050_GMST_RCP4_5=find(trend_diff_2050_sort>0,1,'first')
 
 trend_2020_RCP4_5_sort=sort(trend_2020_RCP4_5(:,1));
 
% Compute 5-95% range
 GMST_trend_2020_RCP4_5_5_95=...
     [trend_2020_RCP4_5_sort(5), trend_2020_RCP4_5_sort(95)]
 
 trend_2035_RCP4_5_sort=sort(trend_2035_RCP4_5(:,1));
 GMST_trend_2035_RCP4_5_5_95=...
     [trend_2035_RCP4_5_sort(5), trend_2035_RCP4_5_sort(95)]
 
 trend_2050_RCP4_5_sort=sort(trend_2050_RCP4_5(:,1));
 GMST_trend_2050_RCP4_5_5_95=...
     [trend_2050_RCP4_5_sort(5), trend_2050_RCP4_5_sort(95)]
 
 print ('GMST_trends_2020_2035_2050_RCP4_5.pdf','-dpdf')

%% Only histogram of trend differences, RCP4.5

 figure(28), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 2.5 27 15]);
 

 trend_diff_2050=trend_2050_RCP4_5-trend_2020_RCP4_5;
 trend_diff_sort=sort(trend_diff);
%  ifast=find(trend_diff_sort>0,1,'first')
 
 binranges=[-1:.025:1];
 trendcount_diff=histc(trend_diff_2050(:,1),binranges);
 hb=bar(binranges,trendcount_diff,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 hold on
 hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
 axis([-.6 .6 0 15.5])
 title('Change in GMST trend, 2050 vs. 2020, RCP4.5','fontsize',28)
%  title('nderung im Temperaturtrend, 2035 vs. 2020','fontsize',28)
 xlabel('K','fontsize',28)
 set(gca,'fontsize',28)

 print ('GMST_trends_2050_vs_2020_RCP4_5.pdf','-dpdf')
 






%% Compute necessary and sufficient probabilities for causality:

% GMST:
 P0 = (ifast_2035_GMST_RCP4_5 - 1)*0.01;
 P1 = (ifast_2035_GMST_RCP2_6 - 1)*0.01;
 PN_GMST_2035 = 1 - P0/P1
 PS_GMST_2035 = (P1 - P0)/(1 - P0)
 PNS_GMST_2035 = P1 - P0
%
 P0 = (ifast_2050_GMST_RCP4_5 - 1)*0.01;
 P1 = (ifast_2050_GMST_RCP2_6 - 1)*0.01;
 PN_GMST_2050 = 1 - P0/P1
 PS_GMST_2050 = (P1 - P0)/(1 - P0)
 PNS_GMST_2050 = P1 - P0
%
 
% % AMOC 26N:
%  P0 = 1 - (ifast_AMOC26N_RCP4_5 - 1)*0.01;      % Slowdown under forcing!
%  P1 = 1 - (ifast_AMOC26N_RCP2_6 - 1)*0.01;
%  PN_AMOC26N = 1 - P0/P1
%  PS_AMOC26N = (P1 - P0)/(1 - P0)
%  PNS_AMOC26N = P1 - P0
% %
% % SIA NH Sep:
%  P0 = 1 - (ifast_SIA_NH_Sep_RCP4_5 - 1)*0.01;
%  P1 = 1 - (ifast_SIA_NH_Sep_RCP2_6 - 1)*0.01;
%  PN_SIA_NH_Sep = 1 - P0/P1
%  PS_SIA_NH_Sep =  (P1 - P0)/(1 - P0)
%  PNS_SIA_NH_Sep = P1 - P0
% %
% % OHC_2000:
%  P0 = (ifast_OHC_2000_RCP4_5 - 1)*0.01;
%  P1 = (ifast_OHC_2000_RCP2_6 - 1)*0.01;
%  PN_OHC_2000 = 1 - P0/P1
%  PS_OHC_2000 =  (P1 - P0)/(1 - P0)
%  PNS_OHC_2000 = P1 - P0
% %

 disp(' ')
 disp(' ')
 disp('*****************************************************************************************')
 disp(['End of run @ ', datestr(now)])
 disp(' ')
 diary off
 
